@@ -2,6 +2,7 @@
 # Copyright (C) 2012, 2013 Satoru SATOH <ssato at redhat.com>
 # License: MIT
 #
+from logging import CRITICAL
 import anyconfig.api as A
 import anyconfig.tests.common as C
 
@@ -32,6 +33,11 @@ class Test_10_pure_functions(unittest.TestCase):
             self.assertEquals(A.find_loader(cpath, "xml"),
                               BXML.XmlConfigParser)
 
+    def test_12_find_loader__w_forced_type__none(self):
+        A.set_loglevel(CRITICAL)  # suppress the logging msg "[Error] ..."
+        cpath = "dummy.conf"
+        self.assertEquals(A.find_loader(cpath, "type_not_exist"), None)
+
     def test_20_find_loader__by_file(self):
         self.assertEquals(A.find_loader("dummy.ini"), BINI.IniConfigParser)
         self.assertEquals(A.find_loader("dummy.json"), BJSON.JsonConfigParser)
@@ -47,6 +53,11 @@ class Test_10_pure_functions(unittest.TestCase):
             self.assertEquals(A.find_loader("dummy.xml"),
                               BXML.XmlConfigParser)
 
+    def test_22_find_loader__by_file__none(self):
+        # see self.test_12_find_loader__w_forced_type__none
+        A.set_loglevel(CRITICAL)
+        self.assertEquals(A.find_loader("dummy.ext_not_found"), None)
+
     def test_30_dumps_and_loads(self):
         a = dict(name="a", a=1, b=dict(b=[1, 2], c="C"))
         a1 = A.loads(A.dumps(a, "json"), "json")
@@ -65,6 +76,15 @@ class Test_10_pure_functions(unittest.TestCase):
         self.assertEquals(a1["b"]["b"], a["b"]["b"])
         self.assertEquals(a1["b"]["c"], a["b"]["c"])
 
+    def test_32_dumps_and_loads__w_options__no_dumper(self):
+        a = dict(name="a", a=1, b=dict(b=[1, 2], c="C"))
+        a1 = A.loads(A.dumps(a, "type_not_exist"), "json")
+
+        self.assertEquals(a1["name"],   a["name"])
+        self.assertEquals(a1["a"],      a["a"])
+        self.assertEquals(a1["b"]["b"], a["b"]["b"])
+        self.assertEquals(a1["b"]["c"], a["b"]["c"])
+
     def test_40_loads_wo_type(self):
         a = dict(requires=["bash", "zsh"])
         a_s = "requires:bash,zsh"
@@ -73,6 +93,14 @@ class Test_10_pure_functions(unittest.TestCase):
 
         self.assertEquals(a1["requires"],   a["requires"])
 
+    def test_42_loads_w_type_not_exist(self):
+        a = dict(requires=["bash", "zsh"])
+        a_s = "requires:bash,zsh"
+
+        a1 = A.loads(a_s, "type_not_exist")
+
+        self.assertEquals(a1["requires"],   a["requires"])
+
 
 class Test_20_effectful_functions(unittest.TestCase):
 
@@ -97,12 +125,25 @@ class Test_20_effectful_functions(unittest.TestCase):
         self.assertEquals(a1["b"]["b"], a["b"]["b"])
         self.assertEquals(a1["b"]["c"], a["b"]["c"])
 
+    def test_12_dump_and_single_load__no_parser(self):
+        self.assertEquals(A.single_load("dummy.ext_not_exist"), None)
+
+    def test_14_single_load__ignore_missing(self):
+        null_cntnr = A.container()
+        cpath = os.path.join(os.curdir, "conf_file_should_not_exist")
+        assert not os.path.exists(cpath)
+
+        self.assertEquals(A.single_load(cpath, forced_type="ini",
+                                        ignore_missing=True),
+                          null_cntnr)
+
     def test_20_dump_and_multi_load(self):
         a = dict(a=1, b=dict(b=[0, 1], c="C"), name="a")
         b = dict(a=2, b=dict(b=[1, 2, 3, 4, 5], d="D"))
 
         a_path = os.path.join(self.workdir, "a.json")
         b_path = os.path.join(self.workdir, "b.json")
+        g_path = os.path.join(self.workdir, "*.json")
 
         A.dump(a, a_path)
         self.assertTrue(os.path.exists(a_path))
@@ -110,6 +151,21 @@ class Test_20_effectful_functions(unittest.TestCase):
         A.dump(b, b_path)
         self.assertTrue(os.path.exists(b_path))
 
+        a0 = A.multi_load(g_path, merge=A.MS_DICTS)
+        a02 = A.multi_load([g_path, b_path], merge=A.MS_DICTS)
+
+        self.assertEquals(a0["name"],   a["name"])
+        self.assertEquals(a0["a"],      b["a"])
+        self.assertEquals(a0["b"]["b"], b["b"]["b"])
+        self.assertEquals(a0["b"]["c"], a["b"]["c"])
+        self.assertEquals(a0["b"]["d"], b["b"]["d"])
+
+        self.assertEquals(a02["name"],   a["name"])
+        self.assertEquals(a02["a"],      b["a"])
+        self.assertEquals(a02["b"]["b"], b["b"]["b"])
+        self.assertEquals(a02["b"]["c"], a["b"]["c"])
+        self.assertEquals(a02["b"]["d"], b["b"]["d"])
+
         a1 = A.multi_load([a_path, b_path], merge=A.MS_DICTS)
 
         self.assertEquals(a1["name"],   a["name"])
@@ -150,6 +206,15 @@ class Test_20_effectful_functions(unittest.TestCase):
         self.assertEquals(a5["b"]["c"], a["b"]["c"])
         self.assertFalse("d" in a5["b"])
 
+    def test_22_multi_load__ignore_missing(self):
+        null_cntnr = A.container()
+        cpath = os.path.join(os.curdir, "conf_file_should_not_exist")
+        assert not os.path.exists(cpath)
+
+        self.assertEquals(A.multi_load([cpath], forced_type="ini",
+                                       ignore_missing=True),
+                          null_cntnr)
+
     def test_30_dump_and_load(self):
         a = dict(a=1, b=dict(b=[0, 1], c="C"), name="a")
         b = dict(a=2, b=dict(b=[1, 2, 3, 4, 5], d="D"))
@@ -186,7 +251,7 @@ class Test_20_effectful_functions(unittest.TestCase):
         self.assertEquals(a3["b"]["c"], a["b"]["c"])
         self.assertEquals(a3["b"]["d"], b["b"]["d"])
 
-    def test_30_dump_and_load__w_options(self):
+    def test_32_dump_and_load__w_options(self):
         a = dict(a=1, b=dict(b=[0, 1], c="C"), name="a")
         b = dict(a=2, b=dict(b=[1, 2, 3, 4, 5], d="D"))
 
@@ -222,4 +287,13 @@ class Test_20_effectful_functions(unittest.TestCase):
         self.assertEquals(a3["b"]["c"], a["b"]["c"])
         self.assertEquals(a3["b"]["d"], b["b"]["d"])
 
+    def test_34_load__ignore_missing(self):
+        null_cntnr = A.container()
+        cpath = os.path.join(os.curdir, "conf_file_should_not_exist")
+        assert not os.path.exists(cpath)
+
+        self.assertEquals(A.load([cpath], forced_type="ini",
+                                 ignore_missing=True),
+                          null_cntnr)
+
 # vim:sw=4:ts=4:et:
