@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2013 Satoru SATOH <ssato @ redhat.com>
+# Copyright (C) 2013, 2014 Satoru SATOH <ssato @ redhat.com>
 # License: MIT
 #
 import anyconfig.globals as TT
@@ -8,7 +8,7 @@ import unittest
 
 class Test_00(unittest.TestCase):
 
-    def test_logger_instance(self):
+    def test_00_logger_instance(self):
         self.assertTrue(isinstance(TT.LOGGER, TT.logging.Logger))
 
 # vim:sw=4:ts=4:et:
